<?php

namespace Litecms\Lead\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Lead\Models\LeadSystem;

class LeadSystemPolicy
{

    /**
     * Determine if the given user can view the lead_system.
     *
     * @param UserPolicyInterface $authUser
     * @param LeadSystem $lead_system
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, LeadSystem $lead_system)
    {
        if ($authUser->canDo('lead.lead_system.view') && $authUser->isAdmin()) {
            return true;
        }

        return $lead_system->user_id == user_id() && $lead_system->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_system.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('lead.lead_system.create');
    }

    /**
     * Determine if the given user can update the given lead_system.
     *
     * @param UserPolicyInterface $authUser
     * @param LeadSystem $lead_system
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, LeadSystem $lead_system)
    {
        if ($authUser->canDo('lead.lead_system.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $lead_system->user_id == user_id() && $lead_system->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_system.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, LeadSystem $lead_system)
    {
        return $lead_system->user_id == user_id() && $lead_system->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_system.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, LeadSystem $lead_system)
    {
        if ($authUser->canDo('lead.lead_system.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_system.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, LeadSystem $lead_system)
    {
        if ($authUser->canDo('lead.lead_system.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
